@@ -1,5 +1,5 @@
 from .core.isql_config import init_isql
-from .core.isql import iSQL, iSqlDF
+from .core.isql import iSQL, iSqlDF, check_sql
 
 from .utils.paths import (
     base_dir, tests_dir, package_dir,
