@@ -81,11 +81,13 @@ def runall(
         else:
             raise ValueError(f"Invalid file or directory : {arg}")
     
-    last_idx = -1
-    for idx, df in rich_func_chainer(isql.run_sql_file, files, console=console):
+    last_idx = 0
+    callback = lambda *args : "subquery" in args[0].name
+    for idx, df in rich_func_chainer(isql.run_sql_file, files, console=console, condition_innerloop=callback):
         if idx is None:
             errors.print(f"🔥 Error: {df}")
-            open(pisql_home / "results" / f"error-{files[last_idx+1].stem}.log", "w+").write(df)
+            write_idx = last_idx+1 if last_idx > 0 else 0
+            open(pisql_home / "results" / f"error-{files[write_idx].stem}.log", "w+").write(str(df))
             continue
         else:
             df.write_parquet(pisql_home / "results" / f"results-{files[idx].stem}.parquet", compression="lz4")
