@@ -9,6 +9,7 @@ import os
 import re
 
 from pathlib import Path
+from collections import Counter
 from typing import List, Tuple, Dict, Union, Optional, Any, Iterator, TypeVar, MutableSequence
 
 from iotree.core.render.funcs import rich_func_chainer
@@ -26,7 +27,28 @@ iSqlError = Dict[str, str]
 iSqlPath = Union[str, os.PathLike, Path]
 iSqlPathList = List[Union[str, os.PathLike, Path]]
 
+
+def renameDupColumns(columns: List[str]) -> List[str]:
+    """Rename duplicate columns from a list of columns"""
+    renamed_columns = []
+    seen = {}
+    for column in columns:
+        if column in seen:
+            seen[column] += 1
+            renamed_columns.append(f"T{seen[column]}.{column}")
+        else:
+            seen[column] = 0
+            renamed_columns.append(column)
+    return renamed_columns
+    
+    return [x for x in columns if not (x in seen or seen_add(x))]
+
 class iSqlDF(pl.DataFrame):
+    def __init__(self, *args, **kwargs):
+        if 'columns' in kwargs:
+            kwargs['columns'] = renameDupColumns(kwargs['columns'])
+        super().__init__(*args, **kwargs)
+
     def __rich_repr__(self, console, options) -> Any:
         return self.asRichTable().__rich_console__(console, options)
     def __rich_console__(self, console, options) -> Any:
@@ -37,8 +59,6 @@ class iSqlDF(pl.DataFrame):
         records = orjson.loads(self.write_json(row_oriented=True))
         return tableFromRecords(records, theme="default")
 
-
-
 def check_sql(txt):
     return (
         'select' in txt.lower() or
