@@ -8,7 +8,6 @@ import re
 
 from typing import List, Tuple, Dict, Union, Optional, Any, Iterator, TypeVar
 from iotree.core.render.tables import tableFromRecords
-from rich.prompt import Prompt, Confirm
 from iotree.core.render.funcs import basic_pbar
 from pathlib import Path
 
@@ -18,12 +17,12 @@ from .core.isql import iSQL
 
 from pisql.utils.paths import (
     base_dir, tests_dir, package_dir,
-    config, assets_dir, data_dir
+    assets_dir, data_dir
 )
 
 from .cli.execute import exe
 from .cli.run import run
-from .cli.config import config, isqlcfg
+from .cli.config import config, iSqlCFG
 
 isql = init_isql()
 
@@ -58,9 +57,9 @@ app.add_typer(run, name="run", no_args_is_help=True, chain=True, help="Run one o
 app.add_typer(run, name="q", no_args_is_help=True, hidden=True, chain=True, )
 app.add_typer(run, name="::", no_args_is_help=True, hidden=True, chain=True)
 
-app.add_typer(cfgapp, name="config", no_args_is_help=True)
-app.add_typer(cfgapp, name="conf", no_args_is_help=True, hidden=True)
-app.add_typer(cfgapp, name="cf", no_args_is_help=True, hidden=True)
+app.add_typer(config, name="config", no_args_is_help=True)
+app.add_typer(config, name="conf", no_args_is_help=True, hidden=True)
+app.add_typer(config, name="cf", no_args_is_help=True, hidden=True)
 
 @dev.command(name="test", help="Run tests 🧪")
 def test(
